Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(675)

Unified Diff: runtime/vm/find_code_object_test.cc

Issue 12663024: Implement optional parameter handling in ARM vm. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/assembler_arm.cc ('k') | runtime/vm/flow_graph_compiler_arm.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/find_code_object_test.cc
===================================================================
--- runtime/vm/find_code_object_test.cc (revision 20390)
+++ runtime/vm/find_code_object_test.cc (working copy)
@@ -13,19 +13,23 @@
namespace dart {
-// Compiler only implemented on IA32 and x64 now.
-#if defined(TARGET_ARCH_IA32) || defined(TARGET_ARCH_X64)
+// Compiler only implemented on IA32, X64, and ARM.
+#if defined(TARGET_ARCH_IA32) || \
+ defined(TARGET_ARCH_X64) || \
+ defined(TARGET_ARCH_ARM)
TEST_CASE(FindCodeObject) {
#if defined(TARGET_ARCH_IA32)
const int kLoopCount = 50000;
+#elif defined(TARGET_ARCH_X64)
+ const int kLoopCount = 25000;
#else
- const int kLoopCount = 25000;
+ const int kLoopCount = 20000;
#endif
const int kScriptSize = 512 * KB;
const int kNumFunctions = 1024;
char scriptChars[kScriptSize];
- String& url = String::Handle(String::New("dart-test:FincCodeObject"));
+ String& url = String::Handle(String::New("dart-test:FindCodeObject"));
String& source = String::Handle();
Script& script = Script::Handle();
Library& lib = Library::Handle();
@@ -152,6 +156,6 @@
EXPECT(Code::LookupCode(pc) == code.raw());
}
-#endif // TARGET_ARCH_IA32 || TARGET_ARCH_X64
+#endif // TARGET_ARCH_IA32 || TARGET_ARCH_X64 || TARGET_ARCH_ARM
} // namespace dart
« no previous file with comments | « runtime/vm/assembler_arm.cc ('k') | runtime/vm/flow_graph_compiler_arm.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698